@@ -803,7 +803,7 @@ class PackageManager:
                 package_details["operation_name"]: operation,
                 "settings": package_class["settings"],
             }
-            if "search_source" == package_type:
+            if package_type == "search_source":
                 del params["check_operation"]
 
             if "endpoint" not in package_class:
@@ -822,7 +822,7 @@ class PackageManager:
                             continue
                     verifyObject(endpoint_class, packages_dict[package_identifier])
                 except colrev_exceptions.ServiceNotAvailableException as sna_exc:
-                    if "docker" == sna_exc.dep:
+                    if sna_exc.dep == "docker":
                         print(
                             f"{colors.ORANGE}Docker not available. Deactivate "
                             f"{package_identifier}{colors.END}"
@@ -885,14 +885,11 @@ class PackageManager:
 
                 endpoint_item["status"] = (
                     endpoint_item["status"]
-                    .replace("GREEN", "🟢")
-                    .replace("ORANGE", "🟡")
-                    .replace("RED", "🔴")
-                )
-                endpoint_item["status_linked"] = (
-                    f"`{endpoint_item['status']} "
-                    + "<https://colrev.readthedocs.io/en/latest/foundations/roadmap.html>`_"
+                    .replace("STABLE", "|STABLE|")
+                    .replace("MATURING", "|MATURING|")
+                    .replace("EXPERIMENTAL", "|EXPERIMENTAL|")
                 )
+                endpoint_item["status_linked"] = endpoint_item["status"]
 
                 # Generate the contents displayed in the docs (see "datatemplate:json")
                 # load short_description dynamically...
@@ -915,24 +912,9 @@ class PackageManager:
                 else:
                     link = code_link
                 # Note: link format for the sphinx docs
-                endpoint_item["link"] = f"`Link <{link}>`_"
-                if (
-                    PackageEndpointType.search_source
-                    == PackageEndpointType[endpoint_type]
-                ):
-                    # Note : heuristic_status is mandatory (interface definition)
-                    endpoint_item["heuristic"] = (
-                        str(endpoint.heuristic_status)
-                        .replace("oni", "ONI")
-                        .replace("supported", "Supported")
-                        .replace("na", "NA")
-                    )
-
-                    if endpoint.api_search_supported:
-                        endpoint_item["api_search"] = "Supported"
-                    else:
-                        endpoint_item["api_search"] = "NA"
-                    endpoint_item["link"] = f"`{endpoint.short_name} <{link}>`_"
+                endpoint_item["short_description"] = (
+                    endpoint_item["short_description"] + f" (`instructions <{link}>`_)"
+                )
 
             endpoint_list += package_endpoints["endpoints"][endpoint_type]
 
