@@ -23,7 +23,7 @@ import colrev.exceptions as colrev_exceptions
 import colrev.record
 import colrev.ui_cli.cli_colors as colors
 
-# pylint: disable=duplicate-code
+
 if False:  # pylint: disable=using-constant-test
     from typing import TYPE_CHECKING
 
@@ -204,7 +204,7 @@ class PaperMarkdown(JsonSchemaMixin):
 
             for commit in commits_list:
                 committer = git_repo.git.show("-s", "--format=%cn", commit.hexsha)
-                if "GitHub" == committer:
+                if committer == "GitHub":
                     continue
                 commits_authors.append(committer)
                 # author = git_repo.git.show("-s", "--format=%an", commit.hexsha)
@@ -285,16 +285,16 @@ class PaperMarkdown(JsonSchemaMixin):
 
                     # skip empty lines between to connect lists
                     line = reader.readline()
-                    if "\n" != line:
+                    if line != "\n":
                         writer.write(line)
 
                     appended = True
 
                 elif appended and not completed:
-                    if "- @" == line[:3]:
+                    if line[:3] == "- @":
                         writer.write(line)
                     else:
-                        if "\n" != line:
+                        if line != "\n":
                             writer.write("\n")
                         writer.write(line)
                         completed = True
@@ -620,7 +620,6 @@ class PaperMarkdown(JsonSchemaMixin):
     def __call_docker_build_process(
         self, *, data_operation: colrev.ops.data.Data, script: str
     ) -> None:
-        # pylint: disable=duplicate-code
         try:
             uid = os.stat(data_operation.review_manager.dataset.records_file).st_uid
             gid = os.stat(data_operation.review_manager.dataset.records_file).st_gid
@@ -799,9 +798,9 @@ class PaperMarkdown(JsonSchemaMixin):
 
         advice = {
             "msg": f"{data_endpoint}"
-            + "\n    1. Edit the paper (data/paper.md)"
+            + "\n    1. Edit the paper (data/data/paper.md)"
             + "\n    2. To build the paper (output/paper.docx), run: colrev data"
-            + "\n    3. To create a version, run: git add data/paper.md && "
+            + "\n    3. To create a version, run: git add data/data/paper.md && "
             + "git commit -m 'update paper'",
             "detailed_msg": "... with a link to the docs etc.",
         }
