@@ -65,7 +65,7 @@ class ZoteroTranslationLoader(JsonSchemaMixin):
         )
 
         headers = {"Content-type": "application/json"}
-        if "No suitable translators found" == ret.content.decode("utf-8"):
+        if ret.content.decode("utf-8") == "No suitable translators found":
             raise colrev_exceptions.ImportException(
                 "Zotero translators: No suitable import translators found"
             )
