@@ -154,7 +154,7 @@ class PDFCompletenessValidation(JsonSchemaMixin):
             page = roman_page_matched.group()
             pages_metadata = f"{__roman_to_int(s=page)}"
 
-        if "NA" == pages_metadata or not re.match(r"^\d+--\d+|\d+$", pages_metadata):
+        if pages_metadata == "NA" or not re.match(r"^\d+--\d+|\d+$", pages_metadata):
             msg = (
                 f'{record.data["ID"]}'.ljust(pad - 1, " ")
                 + "Could not validate completeness: no pages in metadata"
