@@ -145,9 +145,7 @@ class PDFMetadataValidation(JsonSchemaMixin):
             pdf_path = pdf_prep_operation.review_manager.path / Path(
                 record.data["file"]
             )
-            current_cpid = record.get_colrev_pdf_id(
-                review_manager=pdf_prep_operation.review_manager, pdf_path=pdf_path
-            )
+            current_cpid = record.get_colrev_pdf_id(pdf_path=pdf_path)
 
             if "colrev_pdf_id" in retrieved_record:
                 if retrieved_record["colrev_pdf_id"] == str(current_cpid):
