@@ -6,7 +6,6 @@ import json
 from dataclasses import dataclass
 
 import requests
-import timeout_decorator
 import zope.interface
 from dataclasses_jsonschema import JsonSchemaMixin
 
@@ -83,7 +82,6 @@ class CiteAsPrep(JsonSchemaMixin):
         record.add_provenance_all(source=url)
         return record
 
-    @timeout_decorator.timeout(60, use_signals=False)
     def prepare(
         self, prep_operation: colrev.ops.prep.Prep, record: colrev.record.PrepRecord
     ) -> colrev.record.Record:
