@@ -4,7 +4,6 @@ from __future__ import annotations
 
 from dataclasses import dataclass
 
-import timeout_decorator
 import zope.interface
 from alphabet_detector import AlphabetDetector
 from dataclasses_jsonschema import JsonSchemaMixin
@@ -44,7 +43,6 @@ class ExcludeNonLatinAlphabetsPrep(JsonSchemaMixin):
     ) -> None:
         self.settings = self.settings_class.load_settings(data=settings)
 
-    @timeout_decorator.timeout(60, use_signals=False)
     def prepare(
         self,
         prep_operation: colrev.ops.prep.Prep,
