@@ -5,7 +5,6 @@ from __future__ import annotations
 from dataclasses import dataclass
 from pathlib import Path
 
-import timeout_decorator
 import zope.interface
 from dataclasses_jsonschema import JsonSchemaMixin
 
@@ -13,6 +12,7 @@ import colrev.env.package_manager
 import colrev.ops.search_sources
 import colrev.record
 
+# pylint: disable=duplicate-code
 if False:  # pylint: disable=using-constant-test
     from typing import TYPE_CHECKING
 
@@ -45,7 +45,6 @@ class SourceSpecificPrep(JsonSchemaMixin):
             review_manager=prep_operation.review_manager
         )
 
-    @timeout_decorator.timeout(60, use_signals=False)
     def prepare(
         self, prep_operation: colrev.ops.prep.Prep, record: colrev.record.PrepRecord
     ) -> colrev.record.Record:
