@@ -3,7 +3,6 @@
 from __future__ import annotations
 
 from dataclasses import dataclass
-from typing import TYPE_CHECKING
 
 import zope.interface
 from dataclasses_jsonschema import JsonSchemaMixin
@@ -12,8 +11,13 @@ import colrev.env.package_manager
 import colrev.ops.search_sources
 import colrev.record
 
-if TYPE_CHECKING:
-    import colrev.ops.prep
+# pylint: disable=duplicate-code
+
+if False:  # pylint: disable=using-constant-test
+    from typing import TYPE_CHECKING
+
+    if TYPE_CHECKING:
+        import colrev.ops.prep
 
 # pylint: disable=too-few-public-methods
 
@@ -24,6 +28,7 @@ class UpdateMetadataStatusPrep(JsonSchemaMixin):
     """Prepares records by updating the metadata status"""
 
     settings_class = colrev.env.package_manager.DefaultSettings
+    ci_supported: bool = True
 
     source_correction_hint = "check with the developer"
     always_apply_changes = True
@@ -37,11 +42,13 @@ class UpdateMetadataStatusPrep(JsonSchemaMixin):
         self.settings = self.settings_class.load_settings(data=settings)
 
     def prepare(
-        self, prep_operation: colrev.ops.prep.Prep, record: colrev.record.PrepRecord
+        self,
+        prep_operation: colrev.ops.prep.Prep,  # pylint: disable=unused-argument
+        record: colrev.record.PrepRecord,
     ) -> colrev.record.Record:
         """Prepare the record by updating its metadata status"""
 
-        record.update_metadata_status(review_manager=prep_operation.review_manager)
+        record.update_metadata_status()
         return record
 
 
