@@ -15,6 +15,7 @@ from sqlite3 import OperationalError
 from typing import Optional
 
 import requests
+import timeout_decorator
 import zope.interface
 from crossref.restful import Etiquette
 from crossref.restful import Journals
@@ -147,6 +148,7 @@ class CrossrefSearchSource(JsonSchemaMixin):
                     "CROSSREF"
                 ) from exc
 
+    @timeout_decorator.timeout(800, use_signals=False)
     def __query(self, **kwargs) -> typing.Iterator[dict]:  # type: ignore
         """Get records from Crossref based on a bibliographic query"""
 
@@ -161,6 +163,7 @@ class CrossrefSearchSource(JsonSchemaMixin):
         for item in crossref_query_return:
             yield connector_utils.json_to_record(item=item)
 
+    @timeout_decorator.timeout(40, use_signals=False)
     def query_doi(self, *, doi: str) -> colrev.record.PrepRecord:
         """Get records from Crossref based on a doi query"""
 
@@ -184,6 +187,7 @@ class CrossrefSearchSource(JsonSchemaMixin):
 
         return retrieved_record
 
+    @timeout_decorator.timeout(500, use_signals=False)
     def __query_journal(
         self, *, journal_issn: str, rerun: bool
     ) -> typing.Iterator[dict]:
@@ -287,7 +291,12 @@ class CrossrefSearchSource(JsonSchemaMixin):
         prep_main_record: bool = True,
         crossref_source: str = "",
     ) -> colrev.record.Record:
-        self.language_service.unify_to_iso_639_3_language_codes(record=record)
+        if "language" in record.data:
+            try:
+                self.language_service.unify_to_iso_639_3_language_codes(record=record)
+            except colrev_exceptions.InvalidLanguageCodeException:
+                del record.data["language"]
+
         doi_connector.DOIConnector.get_link_from_doi(
             review_manager=self.review_manager,
             record=record,
@@ -315,7 +324,7 @@ class CrossrefSearchSource(JsonSchemaMixin):
         review_manager: colrev.review_manager.ReviewManager,
         record_input: colrev.record.Record,
         jour_vol_iss_list: bool = False,
-        timeout: int = 10,
+        timeout: int = 40,
     ) -> list:
         """Retrieve records from Crossref based on a query"""
 
@@ -389,32 +398,32 @@ class CrossrefSearchSource(JsonSchemaMixin):
 
         return record_list
 
-    def __check_journal(
-        self,
-        prep_operation: colrev.ops.prep.Prep,
-        record: colrev.record.Record,
-        timeout: int,
-        save_feed: bool,
-    ) -> colrev.record.Record:
-        """When there is no doi, journal names can be checked against crossref"""
+    # def __check_journal(
+    #     self,
+    #     prep_operation: colrev.ops.prep.Prep,
+    #     record: colrev.record.Record,
+    #     timeout: int,
+    #     save_feed: bool,
+    # ) -> colrev.record.Record:
+    #     """When there is no doi, journal names can be checked against crossref"""
 
-        if "article" == record.data["ENTRYTYPE"]:
-            # If type article and doi not in record and
-            # journal name not found in journal-query: notify
-            journals = Journals(etiquette=self.etiquette)
-            # record.data["journal"] = "Information Systems Research"
-            found = False
-            ret = journals.query(record.data["journal"])
-            for rets in ret:
-                if rets["title"]:
-                    found = True
-                    break
-            if not found:
-                record.add_masterdata_provenance_note(
-                    key="journal", note="quality_defect:journal not in crossref"
-                )
+    #     if record.data["ENTRYTYPE"] == "article":
+    #         # If type article and doi not in record and
+    #         # journal name not found in journal-query: notify
+    #         journals = Journals(etiquette=self.etiquette)
+    #         # record.data["journal"] = "Information Systems Research"
+    #         found = False
+    #         ret = journals.query(record.data["journal"])
+    #         for rets in ret:
+    #             if rets["title"]:
+    #                 found = True
+    #                 break
+    #         if not found:
+    #             record.add_masterdata_provenance_note(
+    #                 key="journal", note="quality_defect:journal not in crossref"
+    #             )
 
-        return record
+    #     return record
 
     def __get_masterdata_record(
         self,
@@ -547,7 +556,7 @@ class CrossrefSearchSource(JsonSchemaMixin):
         prep_operation: colrev.ops.prep.Prep,
         record: colrev.record.Record,
         save_feed: bool = True,
-        timeout: int = 10,
+        timeout: int = 30,
     ) -> colrev.record.Record:
         """Retrieve masterdata from Crossref based on similarity with the record provided"""
 
@@ -568,13 +577,14 @@ class CrossrefSearchSource(JsonSchemaMixin):
             save_feed=save_feed,
         )
 
-        if "doi" not in record.data:
-            record = self.__check_journal(
-                prep_operation=prep_operation,
-                record=record,
-                timeout=timeout,
-                save_feed=save_feed,
-            )
+        # Note: this should be optional
+        # if "doi" not in record.data:
+        #     record = self.__check_journal(
+        #         prep_operation=prep_operation,
+        #         record=record,
+        #         timeout=timeout,
+        #         save_feed=save_feed,
+        #     )
 
         return record
 
