@@ -33,7 +33,10 @@ class PsycINFOSearchSource(JsonSchemaMixin):
     ci_supported: bool = False
     heuristic_status = colrev.env.package_manager.SearchSourceHeuristicStatus.oni
     short_name = "PsycInfo (APA)"
-    link = "https://www.apa.org/pubs/databases/psycinfo"
+    link = (
+        "https://github.com/CoLRev-Environment/colrev/blob/main/"
+        + "colrev/ops/built_in/search_sources/psycinfo.md"
+    )
 
     def __init__(
         self, *, source_operation: colrev.operation.CheckOperation, settings: dict
