@@ -16,9 +16,8 @@ class ReviewTypes:
         self,
         *,
         review_manager: colrev.review_manager.ReviewManager,
-        review_type: str = None,
+        review_type: str,
     ) -> None:
-
         package_manager = review_manager.get_package_manager()
         check_operation = colrev.operation.CheckOperation(review_manager=review_manager)
 
@@ -27,12 +26,8 @@ class ReviewTypes:
             installed_only=True,
         )
 
-        if review_type:
-            packages_to_load = [{"endpoint": review_type}]
-        else:
-            packages_to_load = [
-                {"endpoint": review_manager.settings.project.review_type}
-            ]
+        packages_to_load = [{"endpoint": review_type}]
+
         self.packages: dict[str, typing.Any] = package_manager.load_packages(
             package_type=colrev.env.package_manager.PackageEndpointType.review_type,
             selected_packages=packages_to_load,
