@@ -9,6 +9,7 @@ from importlib.metadata import version
 from pathlib import Path
 
 import git
+from tqdm import tqdm
 
 import colrev.env.utils
 import colrev.exceptions as colrev_exceptions
@@ -78,7 +79,15 @@ class Upgrade(colrev.operation.Operation):
         settings_version_str = settings["project"]["colrev_version"]
 
         settings_version = CoLRevVersion(settings_version_str)
+        # Start with the first step if the version is older:
+        if settings_version < CoLRevVersion("0.7.0"):
+            settings_version = CoLRevVersion("0.7.0")
+        installed_colrev_version = CoLRevVersion(version("colrev"))
 
+        if installed_colrev_version == settings_version:
+            return
+
+        # version: indicates from which version on the migration should be applied
         migration_scripts: typing.List[typing.Dict[str, typing.Any]] = [
             {
                 "version": CoLRevVersion("0.7.0"),
@@ -93,55 +102,62 @@ class Upgrade(colrev.operation.Operation):
             # Note : we may add a flag to update to pre-released versions
             {
                 "version": CoLRevVersion("0.8.0"),
+                "target_version": CoLRevVersion("0.8.1"),
                 "script": self.__migrate_0_8_0,
                 "released": True,
             },
             {
                 "version": CoLRevVersion("0.8.1"),
+                "target_version": CoLRevVersion("0.8.2"),
                 "script": self.__migrate_0_8_1,
                 "released": True,
             },
+            {
+                "version": CoLRevVersion("0.8.2"),
+                "target_version": CoLRevVersion("0.8.3"),
+                "script": self.__migrate_0_8_2,
+                "released": True,
+            },
         ]
 
-        if settings_version == migration_scripts[-1]["version"]:
-            return
-
-        # Start with the first step if the version is older:
-        if settings_version not in [x["version"] for x in migration_scripts]:
-            settings_version = CoLRevVersion("0.7.0")
+        # Note: we should always update the colrev_version in settings.json because the
+        # checker.__check_software requires the settings version and
+        # the installed version to be identical
 
         # skipping_versions_before_settings_version = True
         run_migration = False
         while migration_scripts:
             migrator = migration_scripts.pop(0)
-
-            # Activate run_migration after the current settings_version
-            if migrator["version"] == settings_version:
+            # Activate run_migration for the current settings_version
+            if (
+                settings_version == migrator["version"]
+            ):  # settings_version == migrator["version"] or
                 run_migration = True
-                continue
             if not run_migration:
                 continue
 
             migration_script = migrator["script"]
+            self.review_manager.logger.info(
+                "Upgrade to: %s", migrator["target_version"]
+            )
+            if migrator["released"]:
+                self.__print_release_notes(selected_version=migrator["target_version"])
 
             updated = migration_script()
             if not updated:
                 continue
-            self.review_manager.logger.info("Update to: %s", migrator["version"])
-            if migrator["released"]:
-                self.__print_release_notes(selected_version=migrator["version"])
 
         settings = self.__load_settings_dict()
-        settings["project"]["colrev_version"] = str(version("colrev"))
+        settings["project"]["colrev_version"] = str(installed_colrev_version)
         self.__save_settings(settings)
 
         if self.repo.is_dirty():
-            msg = str(migrator["version"])
+            msg = f"Upgrade to CoLRev {installed_colrev_version}"
             if not migrator["released"]:
                 msg += " (pre-release)"
-            self.repo.index.commit(
-                msg,
-                skip_hooks=True,
+            review_manager = colrev.review_manager.ReviewManager()
+            review_manager.create_commit(
+                msg=msg,
             )
 
     def __print_release_notes(self, *, selected_version: CoLRevVersion) -> None:
@@ -155,7 +171,7 @@ class Upgrade(colrev.operation.Operation):
                     active = True
                     print(f"{colors.ORANGE}Release notes v{selected_version}")
                     continue
-                if "## [" in line:
+                if line.startswith("## "):
                     active = False
                 if active:
                     print(line)
@@ -255,6 +271,26 @@ class Upgrade(colrev.operation.Operation):
 
         return self.repo.is_dirty()
 
+    def __migrate_0_8_2(self) -> bool:
+        records = self.review_manager.dataset.load_records_dict()
+
+        for record_dict in tqdm(records.values()):
+            if "colrev_pdf_id" not in record_dict:
+                continue
+            if not record_dict["colrev_pdf_id"].startswith("cpid1:"):
+                continue
+            if not Path(record_dict.get("file", "")).is_file():
+                continue
+
+            pdf_path = Path(record_dict["file"])
+            colrev_pdf_id = colrev.record.Record.get_colrev_pdf_id(pdf_path=pdf_path)
+            record_dict["colrev_pdf_id"] = colrev_pdf_id
+
+        self.review_manager.dataset.save_records_dict(records=records)
+        self.review_manager.dataset.add_record_changes()
+
+        return self.repo.is_dirty()
+
 
 class CoLRevVersion:
     """Class for handling the CoLRev version"""
