@@ -11,6 +11,7 @@ from datetime import timedelta
 from pathlib import Path
 from typing import Optional
 
+import git
 import requests_cache
 import yaml
 
@@ -22,6 +23,7 @@ import colrev.logger
 import colrev.operation
 import colrev.record
 import colrev.settings
+import colrev.ui_cli.cli_colors as colors
 from colrev.exit_codes import ExitCodes
 
 
@@ -139,6 +141,13 @@ class ReviewManager:
             self.dataset = colrev.dataset.Dataset(review_manager=self)
 
         except Exception as exc:  # pylint: disable=broad-except
+            if (self.path / Path(".git")).is_dir():
+                if git.Repo().active_branch.name == "gh-pages":
+                    raise colrev_exceptions.RepoSetupError(
+                        msg="Currently on gh-pages branch. Switch to main: "
+                        + f"{colors.ORANGE}git switch main{colors.END}"
+                    )
+
             if force_mode:
                 if debug_mode:
                     self.logger.debug(exc)
@@ -309,6 +318,7 @@ class ReviewManager:
         manual_author: bool = False,
         script_call: str = "",
         saved_args: Optional[dict] = None,
+        skip_status_yaml: bool = False,
     ) -> bool:
         """Create a commit (including a commit report)"""
         import colrev.ops.commit
@@ -323,7 +333,7 @@ class ReviewManager:
             script_name=script_call,
             saved_args=saved_args,
         )
-        ret = commit.create()
+        ret = commit.create(skip_status_yaml=skip_status_yaml)
         return ret
 
     def get_upgrade(self) -> colrev.ops.upgrade.Upgrade:
@@ -461,12 +471,6 @@ class ReviewManager:
 
         return colrev.env.screenshot_service.ScreenshotService(review_manager=self)
 
-    def get_pdf_hash_service(self) -> colrev.env.pdf_hash_service.PDFHashService:
-        """Get the pdf-hash-service object"""
-        import colrev.env.pdf_hash_service
-
-        return colrev.env.pdf_hash_service.PDFHashService(logger=self.logger)
-
     @classmethod
     def get_resources(cls) -> colrev.env.resources.Resources:
         """Get a resources object"""
@@ -474,29 +478,6 @@ class ReviewManager:
 
         return colrev.env.resources.Resources()
 
-    # pylint: disable=too-many-arguments
-    @classmethod
-    def get_init_operation(
-        cls,
-        review_type: str,
-        example: bool = False,
-        light: bool = False,
-        local_pdf_collection: bool = False,
-        target_path: Optional[Path] = None,
-        exact_call: str = "",
-    ) -> colrev.ops.init.Initializer:
-        """Get an init operation object"""
-        import colrev.ops.init
-
-        return colrev.ops.init.Initializer(
-            review_type=review_type,
-            example=example,
-            light=light,
-            local_pdf_collection=local_pdf_collection,
-            target_path=target_path,
-            exact_call=exact_call,
-        )
-
     @classmethod
     def get_sync_operation(cls) -> colrev.ops.sync.Sync:
         """Get a sync operation object"""
@@ -744,5 +725,29 @@ class ReviewManager:
         return any("true" == os.getenv(x) for x in identifier_list)
 
 
+# pylint: disable=redefined-outer-name
+# pylint: disable=import-outside-toplevel
+# pylint: disable=too-many-arguments
+def get_init_operation(
+    review_type: str,
+    example: bool = False,
+    light: bool = False,
+    local_pdf_collection: bool = False,
+    target_path: Optional[Path] = None,
+    exact_call: str = "",
+) -> colrev.ops.init.Initializer:
+    """Get an init operation object"""
+    import colrev.ops.init
+
+    return colrev.ops.init.Initializer(
+        review_type=review_type,
+        example=example,
+        light=light,
+        local_pdf_collection=local_pdf_collection,
+        target_path=target_path,
+        exact_call=exact_call,
+    )
+
+
 if __name__ == "__main__":
     pass
