@@ -159,10 +159,9 @@ def init(
     """Initialize (define review objectives and type)"""
     # pylint: disable=import-outside-toplevel
     import colrev.ops.init
-    import colrev.ui_web.settings_editor
 
     try:
-        colrev.review_manager.ReviewManager.get_init_operation(
+        colrev.review_manager.get_init_operation(
             review_type=type,
             example=example,
             light=light,
@@ -1324,42 +1323,41 @@ def __extract_coverpage(*, cover: Path) -> None:
     )
 
 
-def __print_pdf_hashes(
-    *, pdf_prep_operation: colrev.ops.pdf_prep.PDFPrep, pdf_hash: Path
-) -> None:
+def __print_pdf_hashes(*, pdf_path: Path) -> None:
     # pylint: disable=import-outside-toplevel
     from PyPDF2 import PdfFileReader
+    import colrev.qm.colrev_pdf_id
 
-    assert Path(pdf_hash).suffix == ".pdf"
+    try:
+        pdf_reader = PdfFileReader(str(pdf_path), strict=False)
+    except ValueError:
+        print("Could not read PDF")
+        return
 
-    pdf_hash_service = pdf_prep_operation.review_manager.get_pdf_hash_service()
+    assert Path(pdf_path).suffix == ".pdf"
 
-    first_page_average_hash_16 = pdf_hash_service.get_pdf_hash(
-        pdf_path=Path(pdf_hash),
+    first_page_average_hash_16 = colrev.qm.colrev_pdf_id.get_pdf_hash(
+        pdf_path=Path(pdf_path),
         page_nr=1,
         hash_size=16,
     )
     print(f"first page: {first_page_average_hash_16}")
-    first_page_average_hash_32 = pdf_hash_service.get_pdf_hash(
-        pdf_path=Path(pdf_hash),
+    first_page_average_hash_32 = colrev.qm.colrev_pdf_id.get_pdf_hash(
+        pdf_path=Path(pdf_path),
         page_nr=1,
         hash_size=32,
     )
     print(f"first page: {first_page_average_hash_32}")
 
-    try:
-        pdf_reader = PdfFileReader(str(pdf_hash), strict=False)
-    except ValueError:
-        return
     last_page_nr = len(pdf_reader.pages)
-    last_page_average_hash_16 = pdf_hash_service.get_pdf_hash(
-        pdf_path=Path(pdf_hash),
+    last_page_average_hash_16 = colrev.qm.colrev_pdf_id.get_pdf_hash(
+        pdf_path=Path(pdf_path),
         page_nr=last_page_nr,
         hash_size=16,
     )
     print(f"last page: {last_page_average_hash_16}")
-    last_page_average_hash_32 = pdf_hash_service.get_pdf_hash(
-        pdf_path=Path(pdf_hash),
+    last_page_average_hash_32 = colrev.qm.colrev_pdf_id.get_pdf_hash(
+        pdf_path=Path(pdf_path),
         page_nr=last_page_nr,
         hash_size=32,
     )
@@ -1448,7 +1446,7 @@ def pdf_prep(
         pdf_prep_operation = review_manager.get_pdf_prep_operation(reprocess=reprocess)
 
         if pdf_hash:
-            __print_pdf_hashes(pdf_prep_operation=pdf_prep_operation, pdf_hash=pdf_hash)
+            __print_pdf_hashes(pdf_path=pdf_hash)
 
         elif update_colrev_pdf_ids:
             pdf_prep_operation.update_colrev_pdf_ids()
@@ -1487,7 +1485,7 @@ def __delete_first_pages_cli(
                 )
             else:
                 print("no file in record")
-        if "n" == input("Extract coverpage from another PDF? (y/n)"):
+        if input("Extract coverpage from another PDF? (y/n)") == "n":
             break
         record_id = input("ID of next PDF for coverpage extraction:")
 
@@ -1669,7 +1667,7 @@ def data(
                 )
         else:
             if ret["ask_to_commit"]:
-                if "y" == input("Create commit (y/n)?"):
+                if input("Create commit (y/n)?") == "y":
                     review_manager.create_commit(
                         msg="Data and synthesis", manual_author=True
                     )
@@ -1882,7 +1880,7 @@ def __print_environment_status(
 
     print("\nCoLRev environment status\n")
     print("Index\n")
-    if "up" == environment_details["index"]["status"]:
+    if environment_details["index"]["status"] == "up":
         print(f" - Status: {colors.GREEN}up{colors.END}")
         print(f' - Path          : {environment_details["index"]["path"]}')
         print(f' - Size          : {environment_details["index"]["size"]} records')
@@ -2187,15 +2185,15 @@ def settings(
         review_manager.create_commit(msg="Change settings", manual_author=True)
         return
 
-    import colrev.ui_web.settings_editor
+    # import colrev_ui.ui_web.settings_editor
 
-    review_manager = colrev.review_manager.ReviewManager(
-        force_mode=True, verbose_mode=verbose
-    )
-    settings_operation = colrev.ui_web.settings_editor.SettingsEditor(
-        review_manager=review_manager
-    )
-    settings_operation.open_settings_editor()
+    # review_manager = colrev.review_manager.ReviewManager(
+    #     force_mode=True, verbose_mode=verbose
+    # )
+    # settings_operation = colrev.ui_web.settings_editor.SettingsEditor(
+    #     review_manager=review_manager
+    # )
+    # settings_operation.open_settings_editor()
 
 
 @main.command(help_priority=22)
@@ -2243,10 +2241,10 @@ def sync(
                 print(f"2: {v_2}")
                 print("      " + val[1].data.get("source_url", ""))
                 user_selection = input("Import version 1 or 2 (or skip)?")
-                if "1" == user_selection:
+                if user_selection == "1":
                     sync_operation.add_to_records_to_import(record=val[0])
                     continue
-                if "2" == user_selection:
+                if user_selection == "2":
                     sync_operation.add_to_records_to_import(record=val[1])
                     continue
 
@@ -2417,7 +2415,7 @@ def service(
         print("\nPressed ctrl-c. Shutting down service")
 
     if review_manager.dataset.has_changes():
-        if "y" == input("Commit current changes (y/n)?"):
+        if input("Commit current changes (y/n)?") == "y":
             review_manager.create_commit(msg="Update (using CoLRev service)")
     else:
         print("No changes to commit")
@@ -2459,7 +2457,7 @@ def show(  # type: ignore
     import colrev.operation
     import colrev.ui_cli.show_printer
 
-    if "venv" == keyword:
+    if keyword == "venv":
         colrev.ui_cli.show_printer.print_venv_notes()
         return
 
@@ -2467,18 +2465,18 @@ def show(  # type: ignore
         force_mode=force, verbose_mode=verbose
     )
 
-    if "sample" == keyword:
+    if keyword == "sample":
         colrev.ui_cli.show_printer.print_sample(review_manager=review_manager)
 
-    elif "settings" == keyword:
+    elif keyword == "settings":
         print(f"Settings:\n{review_manager.settings}")
 
-    elif "prisma" == keyword:
+    elif keyword == "prisma":
         status_operation = review_manager.get_status_operation()
         stats_report = status_operation.get_review_status_report()
         print(stats_report)
 
-    elif "cmd_history" == keyword:
+    elif keyword == "cmd_history":
         cmds = []
         colrev.operation.CheckOperation(review_manager=review_manager)
         revlist = review_manager.dataset.get_repo().iter_commits()
@@ -2522,39 +2520,39 @@ def show(  # type: ignore
             )
 
 
-@main.command(help_priority=28)
-@click.option(
-    "-v",
-    "--verbose",
-    is_flag=True,
-    default=False,
-    help="Verbose: printing more infos",
-)
-@click.option(
-    "-f",
-    "--force",
-    is_flag=True,
-    default=False,
-    help="Force mode",
-)
-@click.pass_context
-def web(
-    ctx: click.core.Context,
-    verbose: bool,
-    force: bool,
-) -> None:
-    """CoLRev web interface."""
+# @main.command(help_priority=28)
+# @click.option(
+#     "-v",
+#     "--verbose",
+#     is_flag=True,
+#     default=False,
+#     help="Verbose: printing more infos",
+# )
+# @click.option(
+#     "-f",
+#     "--force",
+#     is_flag=True,
+#     default=False,
+#     help="Force mode",
+# )
+# @click.pass_context
+# def web(
+#     ctx: click.core.Context,
+#     verbose: bool,
+#     force: bool,
+# ) -> None:
+#     """CoLRev web interface."""
 
-    # pylint: disable=import-outside-toplevel
-    import colrev.ui_web.settings_editor
+#     # pylint: disable=import-outside-toplevel
+#     import colrev.ui_web.settings_editor
 
-    review_manager = colrev.review_manager.ReviewManager(
-        force_mode=force, verbose_mode=verbose
-    )
-    se_instance = colrev.ui_web.settings_editor.SettingsEditor(
-        review_manager=review_manager
-    )
-    se_instance.open_settings_editor()
+#     review_manager = colrev.review_manager.ReviewManager(
+#         force_mode=force, verbose_mode=verbose
+#     )
+#     se_instance = colrev.ui_web.settings_editor.SettingsEditor(
+#         review_manager=review_manager
+#     )
+#     se_instance.open_settings_editor()
 
 
 @main.command(hidden=True, help_priority=29)
@@ -2777,7 +2775,7 @@ def undo(
         force_mode=force, verbose_mode=verbose
     )
 
-    if "commit" == selection:
+    if selection == "commit":
         colrev.operation.CheckOperation(review_manager=review_manager)
         git_repo = review_manager.dataset.get_repo()
         git_repo.git.reset("--hard", "HEAD~1")
